@@ -22,7 +22,6 @@ CODE_BUCKET = "airflow-crossref-research-annotation"
 
 PARALLEL_JOBS = 5
 
-import streamlit as st
 import boto3
 
 
@@ -64,44 +63,6 @@ def get_members(
     ]
 
 
-@st.cache_data(ttl=timedelta(hours=24))
-def get_all_members_api():
-    """
-    Retrieves the list of members from the API so we can assign names
-    :return: a dictionary of member information
-    """
-
-    from crossref.restful import Etiquette, Members
-
-    my_etiquette = Etiquette(
-        "Preservation Status", "0.01", "https://eve.gd", "meve@crossref.org"
-    )
-
-    plus_token = st.secrets.get("CROSSREF_PLUS_TOKEN")
-
-    if plus_token:
-        members = Members(
-            etiquette=my_etiquette,
-            crossref_plus_token=plus_token,
-        )
-    else:
-        members = Members(
-            etiquette=my_etiquette,
-        )
-
-    members = members.all()
-
-    output = {}
-
-    try:
-        for member in members:
-            output[member["id"]] = member["primary-name"]
-    except MaxOffsetError:
-        pass
-
-    return output
-
-
 def list_bucket(s3client, samples_bucket, samples_path) -> list[str]:
     """
     Lists the contents of the samples bucket
@@ -714,7 +675,6 @@ def rescore_all(members=None, limit=0):
         )
 
 
-@st.cache_data(ttl=timedelta(hours=24))
 def get_annotation(
     s3client, member_id, annotations_bucket, annotations_path, annotation_name
 ):
